@@ -19,12 +19,19 @@ class AccuracyState:
 class Accuracy(Metric):
     data: AccuracyState
 
+    def __init__(self, ignore_index: int = -1):
+        super().__init__()
+        self.ignore_index = ignore_index
+
     def __call__(self, output: torch.Tensor, target: torch.Tensor):
         output = output.view(-1, output.shape[-1])
         target = target.view(-1)
         pred = output.argmax(dim=-1)
-        self.data.correct += pred.eq(target).sum().item()
-        self.data.samples += len(target)
+        mask = target == self.ignore_index
+        pred.masked_fill_(mask, self.ignore_index)
+        n_masked = mask.sum().item()
+        self.data.correct += pred.eq(target).sum().item() - n_masked
+        self.data.samples += len(target) - n_masked
 
     def create_state(self):
         return AccuracyState()
